/*
 * HCS API
 *
 * No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)
 *
 * API version: 2.1
 * Generated by: Swagger Codegen (https://github.com/swagger-api/swagger-codegen.git)
 */

package hcsschema

type FlexibleIoDevice struct {

	EmulatorId string `json:"EmulatorId,omitempty"`

	HostingModel string `json:"HostingModel,omitempty"`

	Configuration []string `json:"Configuration,omitempty"`
}
